@@ -6,5 +6,9 @@ class Constants(object):
 
     RAD2ARCSEC = 180 * 3600 / np.pi
     ARCSEC2RAD = np.pi / (180 * 3600)
-    RAD2DEG = 180 / np.pi
     DEG2RAD = np.pi / 180
+
+
+RAD2ARCSEC = 180 * 3600 / np.pi
+ARCSEC2RAD = np.pi / (180 * 3600)
+DEG2RAD = np.pi / 180
